!c Description: 
!c   Ķη׻
!c
!c Current Code Owner: 
!c   sugiyama@gfd-dennou.org
!c
!c Copyright (C) SUGIYAMA Ko-ichiro, 2004, All rights reserved


subroutine DistrbType(ss_ExnerDistrb, ss_ThetaDistrb, &
     &               fs_VelXDistrb,  sf_VelZDistrb  )

  use gridset, only: s_X, f_X, s_Z, f_Z, Xmin, Xmax, Zmin, Zmax, &
       &             DimXMin, DimXMax, DimZMin, DimZMax
  use gacchanprm, only: MolWtDry, CpDry, &
       & ExnerDistrbType, ExnerMax, ExnerSigmaX, ExnerSigmaZ, &
       &                  ExnerCenterX, ExnerCenterZ, &
       & ThetaDistrbType, ThetaMax, ThetaSigmaX, ThetaSigmaZ, &
       &                  ThetaCenterX, ThetaCenterZ, &
       & VelDistrbType, VelX, VelZ
  use if_avr

  implicit none

  real(8), intent(out)  :: ss_ThetaDistrb(DimXMin:DimXMax, DimZMin:DimZMax)
  real(8), intent(out)  :: ss_ExnerDistrb(DimXMin:DimXMax, DimZMin:DimZMax)
  real(8), intent(out)  :: fs_VelXDistrb(DimXMin:DimXMax, DimZMin:DimZMax)
  real(8), intent(out)  :: sf_VelZDistrb(DimXMin:DimXMax, DimZMin:DimZMax)

  integer :: i, k
  real(8) :: mu
  real(8) :: sigma

  !--- 
  ss_ExnerDistrb = 0.0d0
  ss_ThetaDistrb = 0.0d0
  fs_VelXDistrb = 0.0d0
  sf_VelZDistrb = 0.0d0
  

  !-----------------------------------------------------------
  !--- ʡؿξ
  !-----------------------------------------------------------
  select case (ExnerDistrbType)

  case ("Exner_Gauss_X")
     !--- X Υʬ
     mu = ( Xmax - Xmin ) * ExnerCenterX
     sigma = ( Xmax - Xmin ) * ExnerSigmaX

     do i = DimXMin, DimXMax
        ss_ExnerDistrb(i,:) = &
             & ExnerMax * dexp(-((s_X(i) - mu) / sigma )**2.0d0 / 2.0d0) 
     end do

  case ("Exner_Gauss_Z")    
     !--- Z Υʬ
     mu = ( Zmax - Zmin ) * ExnerCenterZ
     sigma = ( Zmax - Zmin ) * ExnerSigmaZ

     do k = DimZMin, DimZMax
        ss_ExnerDistrb(:,k) = &
             & ExnerMax * dexp(-((s_Z(k) - mu) / sigma)**2.0d0 / 2.0d0) 
     end do

  case ("Exner_Gauss_XZ")
     !--- Ʊ߾Υʬ
     mu = ( Xmax - Xmin ) * ExnerCenterX
     sigma = ( Xmax - Xmin ) * ExnerSigmaX

     do i = DimXMin, DimXMax
        ss_ExnerDistrb(i,:) = &
             & ExnerMax * dexp(-((s_X(i) - mu) / sigma)**2.0d0 / 2.0d0) 
     end do

     mu = ( Zmax - Zmin ) * ExnerCenterZ
     sigma = ( Zmax - Zmin ) * ExnerSigmaZ
     
     do k = DimZMin, DimZMax
        ss_ExnerDistrb(:,k) = ss_ExnerDistrb(:,k) &
             & * dexp(-((s_Z(k) - mu) / sigma)**2.0d0 / 2.0d0) 
     end do
  end select


  !-----------------------------------------------------------
  !--- ̤ξ
  !-----------------------------------------------------------
  select case (ThetaDistrbType)

  case ("Theta_Gauss_X")
     !--- X Υʬ
     mu = ( Xmax - Xmin ) * ThetaCenterX
     sigma = ( Xmax - Xmin ) * ThetaSigmaX

     do i = DimXMin, DimXMax
        ss_ThetaDistrb(i,:) = &
             & ThetaMax * dexp(-((s_X(i) - mu) / sigma)**2.0d0 / 2.0d0) 
     end do
     
  case ("Theta_Gauss_Z")
     !--- Z Υʬ
     mu = ( Zmax - Zmin ) * ThetaCenterX
     sigma = ( Zmax - Zmin ) * ThetaSigmaZ
     
     do k = DimZMin, DimZMax
        ss_ThetaDistrb(:,k) = &
             & ThetaMax * dexp(-((s_Z(k) - mu) / sigma)**2.0d0 / 2.0d0) 
     end do
     
  case ("Theta_Gauss_XZ")     
     !--- Ʊ߾Υʬ
     mu = ( Xmax - Xmin ) * ThetaCenterX
     sigma = ( Xmax - Xmin ) * ThetaSigmaX
     
     do i = DimXMin, DimXMax
        ss_ThetaDistrb(i,:) = &
             & ThetaMax * dexp(-((s_X(i) - mu) / sigma)**2.0d0 / 2.0d0) 
     end do
     
     mu = ( Zmax - Zmin ) * ThetaCenterZ
     sigma = ( Zmax - Zmin ) * ThetaSigmaZ

     do k = DimZMin, DimZMax
        ss_ThetaDistrb(:,k) =  &
             & ss_ThetaDistrb(:,k) &
             &   * dexp(-((s_Z(k) - mu) / sigma)**2.0d0 / 2.0d0) 
     end do
  end select

     
  !----------------------------------------------------------
  !--- ®
  !----------------------------------------------------------
  select case (VelDistrbType)

  case ("Zero")
     fs_VelXDistrb = 0.0d0
     sf_VelZDistrb = 0.0d0

  case ("VelX_Uniform")
     !--- ® u 
     fs_VelXDistrb = VelX
     sf_VelZDistrb = 0.0d0

  case ("VelZ_Uniform")
     !--- ® w 
     fs_VelXDistrb = 0.0d0
     sf_VelZDistrb = VelZ

  case ("Rotate")
     !--- ΰ濴򼴤Ȥžή
     do k = DimZMin, DimZMax
        fs_VelXDistrb(:,k) = - 5.0d-3 * (f_Z(k) - (ZMax - ZMin) * 5.0d-1) 
     end do
     do i = DimXMin, DimXMax
        sf_VelZDistrb(i,:) = 5.0d-3 * (f_X(i) - (XMax - XMin) * 5.0d-1)
     end do

  end select
        
   
end subroutine DistrbType

